# Generated by Django 2.0.4 on 2018-04-27 15:17

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [("djnexmo", "0003_auto_20180426_1802")]

    operations = [
        migrations.AlterModelOptions(
            name="smsmessagepart", options={"ordering": ("-concat_ref", "concat_part")}
        )
    ]
